@@ -22,7 +22,7 @@ type StateAction interface {
 // "mv <source> <destination>"
 // "rm <addresses>...
 // "import <address> <id>"
-// "xmv <source> <destination>"  // To support moves with wildcards
+// "xmv <source> <destination>"
 func NewStateActionFromString(cmdStr string) (StateAction, error) {
 	args, err := splitStateAction(cmdStr)
 	if err != nil {
@@ -51,7 +51,7 @@ func NewStateActionFromString(cmdStr string) (StateAction, error) {
 		}
 		src := args[1]
 		dst := args[2]
-		action = NewStateXMvAction(src, dst)
+		action = NewStateXmvAction(src, dst)
 
 	case "rm":
 		if len(args) < 2 {
